# - Config to retrieve all components of the gz-sensors7 package
#
# This should only be invoked by gz-sensors7-config.cmake.
#
# To retrieve this meta-package, use:
# find_package(gz-sensors7 COMPONENTS all)
#
# This creates the target gz-sensors7::all which will link to all known
# components of gz-sensors7, including the core library.
#
# This also creates the variable gz-sensors7_ALL_LIBRARIES
#
################################################################################

cmake_minimum_required(VERSION 3.10.2 FATAL_ERROR)

if(gz-sensors7_ALL_CONFIG_INCLUDED)
  return()
endif()
set(gz-sensors7_ALL_CONFIG_INCLUDED TRUE)

if(NOT gz-sensors7-all_FIND_QUIETLY)
  message(STATUS "Looking for all libraries of gz-sensors7 -- found version 7.2.0")
endif()


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was gz-all-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/x86_64-linux-gnu/cmake/gz-sensors7-all" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Get access to the find_dependency utility
include(CMakeFindDependencyMacro)

# Find the core library
find_dependency(gz-sensors7 7.2.0 EXACT)

# Find the component libraries
find_dependency(gz-sensors7-rendering 7.2.0 EXACT)
find_dependency(gz-sensors7-camera 7.2.0 EXACT)
find_dependency(gz-sensors7-depth_camera 7.2.0 EXACT)
find_dependency(gz-sensors7-lidar 7.2.0 EXACT)
find_dependency(gz-sensors7-gpu_lidar 7.2.0 EXACT)
find_dependency(gz-sensors7-logical_camera 7.2.0 EXACT)
find_dependency(gz-sensors7-magnetometer 7.2.0 EXACT)
find_dependency(gz-sensors7-imu 7.2.0 EXACT)
find_dependency(gz-sensors7-altimeter 7.2.0 EXACT)
find_dependency(gz-sensors7-air_pressure 7.2.0 EXACT)
find_dependency(gz-sensors7-air_speed 7.2.0 EXACT)
find_dependency(gz-sensors7-force_torque 7.2.0 EXACT)
find_dependency(gz-sensors7-navsat 7.2.0 EXACT)
find_dependency(gz-sensors7-rgbd_camera 7.2.0 EXACT)
find_dependency(gz-sensors7-thermal_camera 7.2.0 EXACT)
find_dependency(gz-sensors7-boundingbox_camera 7.2.0 EXACT)
find_dependency(gz-sensors7-segmentation_camera 7.2.0 EXACT)
find_dependency(gz-sensors7-wide_angle_camera 7.2.0 EXACT)

if(NOT TARGET gz-sensors7::gz-sensors7-all)
  include("${CMAKE_CURRENT_LIST_DIR}/gz-sensors7-all-targets.cmake")

  add_library(gz-sensors7::all INTERFACE IMPORTED)
  set_target_properties(gz-sensors7::all PROPERTIES
    INTERFACE_LINK_LIBRARIES "gz-sensors7::gz-sensors7-all")

endif()

# Create the "requested" target if it does not already exist
if(NOT TARGET gz-sensors7::requested)
  add_library(gz-sensors7::requested INTERFACE IMPORTED)
endif()

# Link the "all" target to the "requested" target
get_target_property(gz_requested_components gz-sensors7::requested INTERFACE_LINK_LIBRARIES)
if(NOT gz_requested_components)
  set_target_properties(gz-sensors7::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "gz-sensors7::gz-sensors7-all")
else()
  set_target_properties(gz-sensors7::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "${gz_requested_components};gz-sensors7::gz-sensors7-all")
endif()

set(gz-sensors7_ALL_LIBRARIES gz-sensors7::gz-sensors7-all)
